@@ -2,7 +2,7 @@ package Data::Validation;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.23.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.24.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Data::Validation::Constants qw( EXCEPTION_CLASS FALSE HASH NUL SPC );
 use Data::Validation::Constraints;
@@ -79,16 +79,29 @@ my $_compare_fields = sub {
 my $_validate = sub {
    my ($self, $valids, $id, $v) = @_;
 
-   for my $method (grep { $_ ne 'compare' } $_get_methods->( $valids )) {
-      my $attr = { %{ $self->constraints->{ $id } // {} }, method => $method, };
-      my $constraint = Data::Validation::Constraints->new_from_method( $attr );
+   $valids !~ m{ isMandatory }mx and (not defined $v or not length $v)
+      and return;
 
-      $constraint->validate( $v ) and next;
+   my $label = $self->fields->{ $id }->{label} // $id;
 
-     (my $class = $method) =~ s{ \A is }{}mx;
-      my $name  = $self->fields->{ $id }->{label} // $id;
+   for my $methods (grep { $_ ne 'compare' } $_get_methods->( $valids )) {
+      my @fails;
 
-      throw sub { $class }, [ $name, $v ], level => $self->level;
+      for my $method (split m{ [|] }mx, $methods) {
+         my $constraint = Data::Validation::Constraints->new_from_method
+            ( { %{ $self->constraints->{ $id } // {} }, method => $method, } );
+        (my $class = $method) =~ s{ \A is }{}mx;
+
+         if ($constraint->validate( $v )) { @fails = (); last }
+
+         push @fails, $class;
+      }
+
+      @fails == 1 and throw sub { $fails[ 0 ] }, [ $label, $v ],
+                            level => $self->level;
+      @fails  > 1 and throw 'Field [_1] value [_2] is none of [_3]',
+                            [ $label, $v, join ' | ', @fails ],
+                            level => $self->level;
    }
 
    return;
@@ -155,7 +168,7 @@ Data::Validation - Filter and validate data values
 
 =head1 Version
 
-Describes version v0.23.$Rev: 1 $ of L<Data::Validation>
+Describes version v0.24.$Rev: 1 $ of L<Data::Validation>
 
 =head1 Synopsis
 
@@ -216,6 +229,15 @@ separated list of filters to apply and a space separated list of
 constraints. Each constraint method must return true for the value to
 be accepted
 
+The constraint method can also be a list of methods separated by | (pipe)
+characters. This has the effect of requiring only one of the constraints
+to be true
+
+   isMandatory isHexadecimal|isValidNumber
+
+This constraint would require a value that was either hexadecimal or a
+valid number
+
 =item C<filters>
 
 Hash containing filter attributes. Keys are the C<id> values passed
